import * as React from 'react'
import {
  Badge,
  Box,
  Center,
  HStack,
  Icon,
  IconButton,
  List,
  ListItem,
  Text,
  VStack,
} from '@chakra-ui/react'
import prettyBytes from 'pretty-bytes'
import { FaTrash } from 'react-icons/fa'
import { Formalization } from './use-add-formalizations'

export type FormalizationsListProps = {
  formalizations: Formalization[]
  onRemoveFormalization: (index: number) => void
}

export const FormalizationsList: React.FC<FormalizationsListProps> = ({
  formalizations,
  onRemoveFormalization,
}) => {
  return (
    <List w="full" spacing="2">
      {formalizations.map(({ file, name }, index) => {
        const fileExtension = file.name.split('.')[1] ?? ''
        return (
          <ListItem
            id={`formalization-${index}`}
            key={`formalization-${index}`}
            display="flex"
          >
            <VStack w="full">
              <Badge>{name}</Badge>
              <HStack
                spacing="0"
                w="full"
                border="1px"
                borderColor="gray.200"
                borderRadius="sm"
                bg="white"
                width="full"
                height="min-content"
                mt="0"
                minW="0"
                flex="1"
                alignItems="flex-start"
                fontSize="xs"
                h="52px"
              >
                <Center bg="blue.600" borderLeftRadius="base" px="4" h="52px">
                  <Text
                    fontWeight="medium"
                    variant="-1"
                    color="white"
                    textTransform="uppercase"
                  >
                    {fileExtension}
                  </Text>
                </Center>
                <HStack
                  h="full"
                  borderColor="gray.200"
                  borderWidth="px"
                  borderStyle="solid"
                  borderRadius="base"
                  borderLeft="none"
                  borderLeftRadius="none"
                  ml="0"
                  w="full"
                  minWidth="0"
                  flex="1"
                >
                  <VStack
                    justifyContent={file.size ? 'center' : 'flex-start'}
                    spacing="1"
                    pl="3"
                    minW="0"
                    flex="1"
                  >
                    <Text
                      variant="-1"
                      isTruncated={true}
                      w="full"
                      textAlign="center"
                    >
                      {file.name}
                    </Text>

                    <Text variant="-2" color="gray.500">
                      {prettyBytes(file.size ?? 0)}
                    </Text>
                  </VStack>
                  <IconButton
                    aria-label="remove formalization"
                    variant="unstyled"
                    color="blue.400"
                    onClick={() => onRemoveFormalization(index)}
                    icon={<Icon as={FaTrash} />}
                  />
                </HStack>
              </HStack>
            </VStack>
          </ListItem>
        )
      })}
    </List>
  )
}
